@@ -4,6 +4,7 @@ import sys
 import time
 import traceback
 from typing import Tuple, List
+from difflib import unified_diff
 
 import astor
 
@@ -48,9 +49,14 @@ def _fstringify_file(
 
     except Exception as e:
         if not state.quiet:
-            print(f"Skipping fstrings transform of file {filename} due to {e}")
+            if str(e):
+                msg = str(e)
+            else:
+                msg = e.__class__.__name__
+            print(f"Skipping fstrings transform of file {filename} due to {msg}.")
             if state.verbose:
                 traceback.print_exc()
+
         return default_result()
 
     if new_code == contents:
@@ -72,8 +78,12 @@ def _fstringify_file(
         )
         return default_result()
 
-    with open(filename, "w", encoding="utf-8") as f:
-        f.write(new_code)
+    if state.dry_run:
+        for l in unified_diff(contents.split('\n'), new_code.split('\n'), fromfile=filename):
+            print(l)
+    else:
+        with open(filename, "w", encoding="utf-8") as f:
+            f.write(new_code)
 
     return True, changes, len(contents), len(new_code)
 
